    @? result

Evaluates to an unwrapped "success" result value; return `result` if it is a "failure."

If `result` is an `Ok` or a `Some`, `@?` is equivalent to unwrapping the value.  If `result`
is an `Err` or `nothing`, `@?` is equivalent to `return`.

| Invocation       | Equivalent code  |
|:---              |:---              |
| `@? Ok(value)`   | `value`          |
| `@? Err(value)`  | `return value`   |
| `@? Some(value)` | `value`          |
| `@? nothing`     | `return nothing` |

See also: [`@and_return`](@ref), [`and_then`](@ref), [`or_else`](@ref).

# Extended help

## Examples

```julia
using Try, TryExperimental

function try_map_prealloc(f, xs)
    T = @? trygeteltype(xs)  # macro-based short-circuiting
    n = @? trygetlength(xs)
    ys = Vector{T}(undef, n)
    for (i, x) in zip(eachindex(ys), xs)
        ys[i] = f(x)
    end
    return Ok(ys)
end

Try.unwrap(try_map_prealloc(x -> x + 1, 1:3))

# output
3-element Vector{Int64}:
 2
 3
 4
```
